# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="signature.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class Signature(object):
    """The REST response with a document signature collection. This response is returned by the Service when handling any "https://api.aspose.cloud/v4.0/words/Test.doc/signatures" REST API requests.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comments': 'str',
        'issuer_name': 'str',
        'is_valid': 'bool',
        'signature_type': 'str',
        'signature_value': 'str',
        'sign_time': 'datetime',
        'subject_name': 'str'
    }

    attribute_map = {
        'comments': 'Comments',
        'issuer_name': 'IssuerName',
        'is_valid': 'IsValid',
        'signature_type': 'SignatureType',
        'signature_value': 'SignatureValue',
        'sign_time': 'SignTime',
        'subject_name': 'SubjectName'
    }

    def __init__(self, comments=None, issuer_name=None, is_valid=None, signature_type=None, signature_value=None, sign_time=None, subject_name=None):  # noqa: E501
        """Signature - a model defined in Swagger"""  # noqa: E501

        self._comments = None
        self._issuer_name = None
        self._is_valid = None
        self._signature_type = None
        self._signature_value = None
        self._sign_time = None
        self._subject_name = None
        self.discriminator = None

        if comments is not None:
            self.comments = comments
        if issuer_name is not None:
            self.issuer_name = issuer_name
        if is_valid is not None:
            self.is_valid = is_valid
        if signature_type is not None:
            self.signature_type = signature_type
        if signature_value is not None:
            self.signature_value = signature_value
        if sign_time is not None:
            self.sign_time = sign_time
        if subject_name is not None:
            self.subject_name = subject_name

    @property
    def comments(self):
        """Gets the comments of this Signature.  # noqa: E501

        Gets or sets the signing purpose comment.  # noqa: E501

        :return: The comments of this Signature.  # noqa: E501
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this Signature.

        Gets or sets the signing purpose comment.  # noqa: E501

        :param comments: The comments of this Signature.  # noqa: E501
        :type: str
        """
        self._comments = comments

    @property
    def issuer_name(self):
        """Gets the issuer_name of this Signature.  # noqa: E501

        Gets or sets the subject distinguished name of the certificate isuuer.  # noqa: E501

        :return: The issuer_name of this Signature.  # noqa: E501
        :rtype: str
        """
        return self._issuer_name

    @issuer_name.setter
    def issuer_name(self, issuer_name):
        """Sets the issuer_name of this Signature.

        Gets or sets the subject distinguished name of the certificate isuuer.  # noqa: E501

        :param issuer_name: The issuer_name of this Signature.  # noqa: E501
        :type: str
        """
        self._issuer_name = issuer_name

    @property
    def is_valid(self):
        """Gets the is_valid of this Signature.  # noqa: E501

        Gets or sets a value indicating whether this digital signature is valid.  # noqa: E501

        :return: The is_valid of this Signature.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this Signature.

        Gets or sets a value indicating whether this digital signature is valid.  # noqa: E501

        :param is_valid: The is_valid of this Signature.  # noqa: E501
        :type: bool
        """
        self._is_valid = is_valid

    @property
    def signature_type(self):
        """Gets the signature_type of this Signature.  # noqa: E501

        Gets or sets the type of the digital signature.  # noqa: E501

        :return: The signature_type of this Signature.  # noqa: E501
        :rtype: str
        """
        return self._signature_type

    @signature_type.setter
    def signature_type(self, signature_type):
        """Sets the signature_type of this Signature.

        Gets or sets the type of the digital signature.  # noqa: E501

        :param signature_type: The signature_type of this Signature.  # noqa: E501
        :type: str
        """
        self._signature_type = signature_type

    @property
    def signature_value(self):
        """Gets the signature_value of this Signature.  # noqa: E501

        Gets or sets an array of bytes representing a signature value as base64 string.  # noqa: E501

        :return: The signature_value of this Signature.  # noqa: E501
        :rtype: str
        """
        return self._signature_value

    @signature_value.setter
    def signature_value(self, signature_value):
        """Sets the signature_value of this Signature.

        Gets or sets an array of bytes representing a signature value as base64 string.  # noqa: E501

        :param signature_value: The signature_value of this Signature.  # noqa: E501
        :type: str
        """
        self._signature_value = signature_value

    @property
    def sign_time(self):
        """Gets the sign_time of this Signature.  # noqa: E501

        Gets or sets the time the document was signed.  # noqa: E501

        :return: The sign_time of this Signature.  # noqa: E501
        :rtype: datetime
        """
        return self._sign_time

    @sign_time.setter
    def sign_time(self, sign_time):
        """Sets the sign_time of this Signature.

        Gets or sets the time the document was signed.  # noqa: E501

        :param sign_time: The sign_time of this Signature.  # noqa: E501
        :type: datetime
        """
        self._sign_time = sign_time

    @property
    def subject_name(self):
        """Gets the subject_name of this Signature.  # noqa: E501

        Gets or sets the subject distinguished name of the certificate that was used to sign the document.  # noqa: E501

        :return: The subject_name of this Signature.  # noqa: E501
        :rtype: str
        """
        return self._subject_name

    @subject_name.setter
    def subject_name(self, subject_name):
        """Sets the subject_name of this Signature.

        Gets or sets the subject distinguished name of the certificate that was used to sign the document.  # noqa: E501

        :param subject_name: The subject_name of this Signature.  # noqa: E501
        :type: str
        """
        self._subject_name = subject_name


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._is_valid is None:
            raise ValueError("Property IsValid in Signature is required.")  # noqa: E501
        if self._sign_time is None:
            raise ValueError("Property SignTime in Signature is required.")  # noqa: E501

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Signature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="form_field_checkbox.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class FormFieldCheckbox(object):
    """FormField checkbox element.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'node_id': 'str',
        'name': 'str',
        'enabled': 'bool',
        'status_text': 'str',
        'own_status': 'bool',
        'help_text': 'str',
        'own_help': 'bool',
        'calculate_on_exit': 'bool',
        'entry_macro': 'str',
        'exit_macro': 'str',
        'is_check_box_exact_size': 'bool',
        'check_box_size': 'float',
        'checked': 'bool'
    }

    attribute_map = {
        'link': 'Link',
        'node_id': 'NodeId',
        'name': 'Name',
        'enabled': 'Enabled',
        'status_text': 'StatusText',
        'own_status': 'OwnStatus',
        'help_text': 'HelpText',
        'own_help': 'OwnHelp',
        'calculate_on_exit': 'CalculateOnExit',
        'entry_macro': 'EntryMacro',
        'exit_macro': 'ExitMacro',
        'is_check_box_exact_size': 'IsCheckBoxExactSize',
        'check_box_size': 'CheckBoxSize',
        'checked': 'Checked'
    }

    def __init__(self, link=None, node_id=None, name=None, enabled=None, status_text=None, own_status=None, help_text=None, own_help=None, calculate_on_exit=None, entry_macro=None, exit_macro=None, is_check_box_exact_size=None, check_box_size=None, checked=None):  # noqa: E501
        """FormFieldCheckbox - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._node_id = None
        self._name = None
        self._enabled = None
        self._status_text = None
        self._own_status = None
        self._help_text = None
        self._own_help = None
        self._calculate_on_exit = None
        self._entry_macro = None
        self._exit_macro = None
        self._is_check_box_exact_size = None
        self._check_box_size = None
        self._checked = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if node_id is not None:
            self.node_id = node_id
        if name is not None:
            self.name = name
        if enabled is not None:
            self.enabled = enabled
        if status_text is not None:
            self.status_text = status_text
        if own_status is not None:
            self.own_status = own_status
        if help_text is not None:
            self.help_text = help_text
        if own_help is not None:
            self.own_help = own_help
        if calculate_on_exit is not None:
            self.calculate_on_exit = calculate_on_exit
        if entry_macro is not None:
            self.entry_macro = entry_macro
        if exit_macro is not None:
            self.exit_macro = exit_macro
        if is_check_box_exact_size is not None:
            self.is_check_box_exact_size = is_check_box_exact_size
        if check_box_size is not None:
            self.check_box_size = check_box_size
        if checked is not None:
            self.checked = checked

    @property
    def link(self):
        """Gets the link of this FormFieldCheckbox.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this FormFieldCheckbox.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this FormFieldCheckbox.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this FormFieldCheckbox.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def node_id(self):
        """Gets the node_id of this FormFieldCheckbox.  # noqa: E501

        Gets or sets the node id.  # noqa: E501

        :return: The node_id of this FormFieldCheckbox.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this FormFieldCheckbox.

        Gets or sets the node id.  # noqa: E501

        :param node_id: The node_id of this FormFieldCheckbox.  # noqa: E501
        :type: str
        """
        self._node_id = node_id

    @property
    def name(self):
        """Gets the name of this FormFieldCheckbox.  # noqa: E501

        Gets or sets the form field name.  # noqa: E501

        :return: The name of this FormFieldCheckbox.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FormFieldCheckbox.

        Gets or sets the form field name.  # noqa: E501

        :param name: The name of this FormFieldCheckbox.  # noqa: E501
        :type: str
        """
        self._name = name

    @property
    def enabled(self):
        """Gets the enabled of this FormFieldCheckbox.  # noqa: E501

        Gets or sets a value indicating whether a form field is enabled. If a form field is enabled, its contents can be changed as the form is filled in.  # noqa: E501

        :return: The enabled of this FormFieldCheckbox.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this FormFieldCheckbox.

        Gets or sets a value indicating whether a form field is enabled. If a form field is enabled, its contents can be changed as the form is filled in.  # noqa: E501

        :param enabled: The enabled of this FormFieldCheckbox.  # noqa: E501
        :type: bool
        """
        self._enabled = enabled

    @property
    def status_text(self):
        """Gets the status_text of this FormFieldCheckbox.  # noqa: E501

        Gets or sets text, displayed in the status bar when a form field has the focus. If the OwnStatus property is set to true, the StatusText property specifies the status bar text. If the OwnStatus property is set to false, the StatusText property specifies the name of an AutoText entry that contains status bar text for the form field.  # noqa: E501

        :return: The status_text of this FormFieldCheckbox.  # noqa: E501
        :rtype: str
        """
        return self._status_text

    @status_text.setter
    def status_text(self, status_text):
        """Sets the status_text of this FormFieldCheckbox.

        Gets or sets text, displayed in the status bar when a form field has the focus. If the OwnStatus property is set to true, the StatusText property specifies the status bar text. If the OwnStatus property is set to false, the StatusText property specifies the name of an AutoText entry that contains status bar text for the form field.  # noqa: E501

        :param status_text: The status_text of this FormFieldCheckbox.  # noqa: E501
        :type: str
        """
        self._status_text = status_text

    @property
    def own_status(self):
        """Gets the own_status of this FormFieldCheckbox.  # noqa: E501

        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus. If true, the text specified by the StatusText property is displayed. If false, the text of the AutoText entry specified by the StatusText property is displayed.  # noqa: E501

        :return: The own_status of this FormFieldCheckbox.  # noqa: E501
        :rtype: bool
        """
        return self._own_status

    @own_status.setter
    def own_status(self, own_status):
        """Sets the own_status of this FormFieldCheckbox.

        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus. If true, the text specified by the StatusText property is displayed. If false, the text of the AutoText entry specified by the StatusText property is displayed.  # noqa: E501

        :param own_status: The own_status of this FormFieldCheckbox.  # noqa: E501
        :type: bool
        """
        self._own_status = own_status

    @property
    def help_text(self):
        """Gets the help_text of this FormFieldCheckbox.  # noqa: E501

        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1. If the OwnHelp property is set to True, HelpText specifies the text string value. If OwnHelp is set to False, HelpText specifies the name of an AutoText entry that contains help text for the form field.  # noqa: E501

        :return: The help_text of this FormFieldCheckbox.  # noqa: E501
        :rtype: str
        """
        return self._help_text

    @help_text.setter
    def help_text(self, help_text):
        """Sets the help_text of this FormFieldCheckbox.

        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1. If the OwnHelp property is set to True, HelpText specifies the text string value. If OwnHelp is set to False, HelpText specifies the name of an AutoText entry that contains help text for the form field.  # noqa: E501

        :param help_text: The help_text of this FormFieldCheckbox.  # noqa: E501
        :type: str
        """
        self._help_text = help_text

    @property
    def own_help(self):
        """Gets the own_help of this FormFieldCheckbox.  # noqa: E501

        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1. If True, the text specified by the HelpText property is displayed. If False, the text in the AutoText entry specified by the HelpText property is displayed.  # noqa: E501

        :return: The own_help of this FormFieldCheckbox.  # noqa: E501
        :rtype: bool
        """
        return self._own_help

    @own_help.setter
    def own_help(self, own_help):
        """Sets the own_help of this FormFieldCheckbox.

        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1. If True, the text specified by the HelpText property is displayed. If False, the text in the AutoText entry specified by the HelpText property is displayed.  # noqa: E501

        :param own_help: The own_help of this FormFieldCheckbox.  # noqa: E501
        :type: bool
        """
        self._own_help = own_help

    @property
    def calculate_on_exit(self):
        """Gets the calculate_on_exit of this FormFieldCheckbox.  # noqa: E501

        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited. Setting CalculateOnExit only affects the behavior of the form field when the document is opened in Microsoft Word. Aspose.Words never updates references to the form field.  # noqa: E501

        :return: The calculate_on_exit of this FormFieldCheckbox.  # noqa: E501
        :rtype: bool
        """
        return self._calculate_on_exit

    @calculate_on_exit.setter
    def calculate_on_exit(self, calculate_on_exit):
        """Sets the calculate_on_exit of this FormFieldCheckbox.

        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited. Setting CalculateOnExit only affects the behavior of the form field when the document is opened in Microsoft Word. Aspose.Words never updates references to the form field.  # noqa: E501

        :param calculate_on_exit: The calculate_on_exit of this FormFieldCheckbox.  # noqa: E501
        :type: bool
        """
        self._calculate_on_exit = calculate_on_exit

    @property
    def entry_macro(self):
        """Gets the entry_macro of this FormFieldCheckbox.  # noqa: E501

        Gets or sets the entry macro name for the form field. The entry macro runs when the form field gets the focus in Microsoft Word.  # noqa: E501

        :return: The entry_macro of this FormFieldCheckbox.  # noqa: E501
        :rtype: str
        """
        return self._entry_macro

    @entry_macro.setter
    def entry_macro(self, entry_macro):
        """Sets the entry_macro of this FormFieldCheckbox.

        Gets or sets the entry macro name for the form field. The entry macro runs when the form field gets the focus in Microsoft Word.  # noqa: E501

        :param entry_macro: The entry_macro of this FormFieldCheckbox.  # noqa: E501
        :type: str
        """
        self._entry_macro = entry_macro

    @property
    def exit_macro(self):
        """Gets the exit_macro of this FormFieldCheckbox.  # noqa: E501

        Gets or sets the exit macro name for the form field. The exit macro runs when the form field loses the focus in Microsoft Word.  # noqa: E501

        :return: The exit_macro of this FormFieldCheckbox.  # noqa: E501
        :rtype: str
        """
        return self._exit_macro

    @exit_macro.setter
    def exit_macro(self, exit_macro):
        """Sets the exit_macro of this FormFieldCheckbox.

        Gets or sets the exit macro name for the form field. The exit macro runs when the form field loses the focus in Microsoft Word.  # noqa: E501

        :param exit_macro: The exit_macro of this FormFieldCheckbox.  # noqa: E501
        :type: str
        """
        self._exit_macro = exit_macro

    @property
    def is_check_box_exact_size(self):
        """Gets the is_check_box_exact_size of this FormFieldCheckbox.  # noqa: E501

        Gets or sets a value indicating whether the size of the textbox is automatic or specified explicitly.  # noqa: E501

        :return: The is_check_box_exact_size of this FormFieldCheckbox.  # noqa: E501
        :rtype: bool
        """
        return self._is_check_box_exact_size

    @is_check_box_exact_size.setter
    def is_check_box_exact_size(self, is_check_box_exact_size):
        """Sets the is_check_box_exact_size of this FormFieldCheckbox.

        Gets or sets a value indicating whether the size of the textbox is automatic or specified explicitly.  # noqa: E501

        :param is_check_box_exact_size: The is_check_box_exact_size of this FormFieldCheckbox.  # noqa: E501
        :type: bool
        """
        self._is_check_box_exact_size = is_check_box_exact_size

    @property
    def check_box_size(self):
        """Gets the check_box_size of this FormFieldCheckbox.  # noqa: E501

        Gets or sets the size of the checkbox in points. Has effect only when IsCheckBoxExactSize is true.  # noqa: E501

        :return: The check_box_size of this FormFieldCheckbox.  # noqa: E501
        :rtype: float
        """
        return self._check_box_size

    @check_box_size.setter
    def check_box_size(self, check_box_size):
        """Sets the check_box_size of this FormFieldCheckbox.

        Gets or sets the size of the checkbox in points. Has effect only when IsCheckBoxExactSize is true.  # noqa: E501

        :param check_box_size: The check_box_size of this FormFieldCheckbox.  # noqa: E501
        :type: float
        """
        self._check_box_size = check_box_size

    @property
    def checked(self):
        """Gets the checked of this FormFieldCheckbox.  # noqa: E501

        Gets or sets the checked status of the check box form field.  # noqa: E501

        :return: The checked of this FormFieldCheckbox.  # noqa: E501
        :rtype: bool
        """
        return self._checked

    @checked.setter
    def checked(self, checked):
        """Sets the checked of this FormFieldCheckbox.

        Gets or sets the checked status of the check box form field.  # noqa: E501

        :param checked: The checked of this FormFieldCheckbox.  # noqa: E501
        :type: bool
        """
        self._checked = checked


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._name is None:
            raise ValueError("Property Name in FormFieldCheckbox is required.")  # noqa: E501
        if self._checked is None:
            raise ValueError("Property Checked in FormFieldCheckbox is required.")  # noqa: E501

        if self._link is not None:
            self._link.validate()















    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormFieldCheckbox):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="test_url_encode.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import os
import asposewordscloud.models.requests
from test.base_test_context import BaseTestContext


class TestUrlEncode(BaseTestContext):

    test_folder = 'DocumentElements/Bookmarks'

    #
    # Test for url encoding of document name
    #
    def test_url_encode(self):
        filename = 'test_multi_pages.docx'
        remote_name = '[“Test_Two,_Inc.”]-_83(b)Election([“Bill_Gates”]).docx'
        bookmark_name = 'aspose'
        self.upload_file(os.path.join(self.remote_test_folder, self.test_folder, remote_name), open(os.path.join(self.local_test_folder, self.local_common_folder, filename), 'rb'))
        request = asposewordscloud.models.requests.GetBookmarkByNameRequest(remote_name, bookmark_name,
                                                                                  os.path.join(
                                                                                      self.remote_test_folder,
                                                                                      self.test_folder))
        result = self.words_api.get_bookmark_by_name(request)
        self.assertIsNotNone(result, 'Error has occurred while get document bookmark by name')



# coding: utf-8

# flake8: noqa

from __future__ import absolute_import

# import apis into sdk package
from asposewordscloud.apis.words_api import WordsApi
# import ApiClient
from asposewordscloud.api_client import ApiClient
from asposewordscloud.configuration import Configuration
# import models into sdk package
from asposewordscloud.models.file_reference import FileReference
from asposewordscloud.models.api_error import ApiError
from asposewordscloud.models.available_fonts_response import AvailableFontsResponse
from asposewordscloud.models.azw3_save_options_data import Azw3SaveOptionsData
from asposewordscloud.models.bmp_save_options_data import BmpSaveOptionsData
from asposewordscloud.models.bookmark import Bookmark
from asposewordscloud.models.bookmark_data import BookmarkData
from asposewordscloud.models.bookmark_insert import BookmarkInsert
from asposewordscloud.models.bookmark_response import BookmarkResponse
from asposewordscloud.models.bookmarks import Bookmarks
from asposewordscloud.models.bookmarks_outline_level_data import BookmarksOutlineLevelData
from asposewordscloud.models.bookmarks_response import BookmarksResponse
from asposewordscloud.models.border import Border
from asposewordscloud.models.border_response import BorderResponse
from asposewordscloud.models.borders_collection import BordersCollection
from asposewordscloud.models.borders_response import BordersResponse
from asposewordscloud.models.classification_response import ClassificationResponse
from asposewordscloud.models.classification_result import ClassificationResult
from asposewordscloud.models.comment import Comment
from asposewordscloud.models.comment_insert import CommentInsert
from asposewordscloud.models.comment_link import CommentLink
from asposewordscloud.models.comment_range_end import CommentRangeEnd
from asposewordscloud.models.comment_range_start import CommentRangeStart
from asposewordscloud.models.comment_response import CommentResponse
from asposewordscloud.models.comments_collection import CommentsCollection
from asposewordscloud.models.comments_response import CommentsResponse
from asposewordscloud.models.comment_update import CommentUpdate
from asposewordscloud.models.compare_data import CompareData
from asposewordscloud.models.compare_options import CompareOptions
from asposewordscloud.models.compress_options import CompressOptions
from asposewordscloud.models.compress_response import CompressResponse
from asposewordscloud.models.csv_data_load_options import CsvDataLoadOptions
from asposewordscloud.models.custom_xml_part import CustomXmlPart
from asposewordscloud.models.custom_xml_part_insert import CustomXmlPartInsert
from asposewordscloud.models.custom_xml_part_link import CustomXmlPartLink
from asposewordscloud.models.custom_xml_part_response import CustomXmlPartResponse
from asposewordscloud.models.custom_xml_parts_collection import CustomXmlPartsCollection
from asposewordscloud.models.custom_xml_parts_response import CustomXmlPartsResponse
from asposewordscloud.models.custom_xml_part_update import CustomXmlPartUpdate
from asposewordscloud.models.digital_signature_details import DigitalSignatureDetails
from asposewordscloud.models.docm_save_options_data import DocmSaveOptionsData
from asposewordscloud.models.doc_save_options_data import DocSaveOptionsData
from asposewordscloud.models.document import Document
from asposewordscloud.models.document_entry import DocumentEntry
from asposewordscloud.models.document_entry_list import DocumentEntryList
from asposewordscloud.models.document_position import DocumentPosition
from asposewordscloud.models.document_properties import DocumentProperties
from asposewordscloud.models.document_properties_response import DocumentPropertiesResponse
from asposewordscloud.models.document_property import DocumentProperty
from asposewordscloud.models.document_property_create_or_update import DocumentPropertyCreateOrUpdate
from asposewordscloud.models.document_property_response import DocumentPropertyResponse
from asposewordscloud.models.document_response import DocumentResponse
from asposewordscloud.models.document_stat_data import DocumentStatData
from asposewordscloud.models.docx_save_options_data import DocxSaveOptionsData
from asposewordscloud.models.dotm_save_options_data import DotmSaveOptionsData
from asposewordscloud.models.dot_save_options_data import DotSaveOptionsData
from asposewordscloud.models.dotx_save_options_data import DotxSaveOptionsData
from asposewordscloud.models.downsample_options_data import DownsampleOptionsData
from asposewordscloud.models.drawing_object import DrawingObject
from asposewordscloud.models.drawing_object_collection import DrawingObjectCollection
from asposewordscloud.models.drawing_object_insert import DrawingObjectInsert
from asposewordscloud.models.drawing_object_link import DrawingObjectLink
from asposewordscloud.models.drawing_object_response import DrawingObjectResponse
from asposewordscloud.models.drawing_objects_response import DrawingObjectsResponse
from asposewordscloud.models.drawing_object_update import DrawingObjectUpdate
from asposewordscloud.models.emf_save_options_data import EmfSaveOptionsData
from asposewordscloud.models.eps_save_options_data import EpsSaveOptionsData
from asposewordscloud.models.epub_save_options_data import EpubSaveOptionsData
from asposewordscloud.models.error import Error
from asposewordscloud.models.error_details import ErrorDetails
from asposewordscloud.models.field import Field
from asposewordscloud.models.field_collection import FieldCollection
from asposewordscloud.models.field_insert import FieldInsert
from asposewordscloud.models.field_link import FieldLink
from asposewordscloud.models.field_names import FieldNames
from asposewordscloud.models.field_names_response import FieldNamesResponse
from asposewordscloud.models.field_options import FieldOptions
from asposewordscloud.models.field_response import FieldResponse
from asposewordscloud.models.fields_response import FieldsResponse
from asposewordscloud.models.field_update import FieldUpdate
from asposewordscloud.models.file_link import FileLink
from asposewordscloud.models.files_list import FilesList
from asposewordscloud.models.files_upload_result import FilesUploadResult
from asposewordscloud.models.flat_opc_macro_save_options_data import FlatOpcMacroSaveOptionsData
from asposewordscloud.models.flat_opc_save_options_data import FlatOpcSaveOptionsData
from asposewordscloud.models.flat_opc_template_macro_save_options_data import FlatOpcTemplateMacroSaveOptionsData
from asposewordscloud.models.flat_opc_template_save_options_data import FlatOpcTemplateSaveOptionsData
from asposewordscloud.models.font import Font
from asposewordscloud.models.font_info import FontInfo
from asposewordscloud.models.font_response import FontResponse
from asposewordscloud.models.footnote import Footnote
from asposewordscloud.models.footnote_collection import FootnoteCollection
from asposewordscloud.models.footnote_insert import FootnoteInsert
from asposewordscloud.models.footnote_link import FootnoteLink
from asposewordscloud.models.footnote_response import FootnoteResponse
from asposewordscloud.models.footnotes_response import FootnotesResponse
from asposewordscloud.models.footnotes_stat_data import FootnotesStatData
from asposewordscloud.models.footnote_update import FootnoteUpdate
from asposewordscloud.models.form_field_checkbox import FormFieldCheckbox
from asposewordscloud.models.form_field_checkbox_link import FormFieldCheckboxLink
from asposewordscloud.models.form_field_collection import FormFieldCollection
from asposewordscloud.models.form_field_drop_down import FormFieldDropDown
from asposewordscloud.models.form_field_drop_down_link import FormFieldDropDownLink
from asposewordscloud.models.form_field_response import FormFieldResponse
from asposewordscloud.models.form_fields_response import FormFieldsResponse
from asposewordscloud.models.form_field_text_input import FormFieldTextInput
from asposewordscloud.models.form_field_text_input_link import FormFieldTextInputLink
from asposewordscloud.models.gif_save_options_data import GifSaveOptionsData
from asposewordscloud.models.header_footer import HeaderFooter
from asposewordscloud.models.header_footer_link import HeaderFooterLink
from asposewordscloud.models.header_footer_link_collection import HeaderFooterLinkCollection
from asposewordscloud.models.header_footer_response import HeaderFooterResponse
from asposewordscloud.models.header_footers_response import HeaderFootersResponse
from asposewordscloud.models.html_fixed_save_options_data import HtmlFixedSaveOptionsData
from asposewordscloud.models.html_save_options_data import HtmlSaveOptionsData
from asposewordscloud.models.hyperlink import Hyperlink
from asposewordscloud.models.hyperlink_response import HyperlinkResponse
from asposewordscloud.models.hyperlinks import Hyperlinks
from asposewordscloud.models.hyperlinks_response import HyperlinksResponse
from asposewordscloud.models.image_entry import ImageEntry
from asposewordscloud.models.image_entry_list import ImageEntryList
from asposewordscloud.models.info_additional_item import InfoAdditionalItem
from asposewordscloud.models.info_response import InfoResponse
from asposewordscloud.models.jpeg_save_options_data import JpegSaveOptionsData
from asposewordscloud.models.json_data_load_options import JsonDataLoadOptions
from asposewordscloud.models.link import Link
from asposewordscloud.models.link_element import LinkElement
from asposewordscloud.models.list_format import ListFormat
from asposewordscloud.models.list_format_update import ListFormatUpdate
from asposewordscloud.models.list_info import ListInfo
from asposewordscloud.models.list_insert import ListInsert
from asposewordscloud.models.list_level import ListLevel
from asposewordscloud.models.list_levels import ListLevels
from asposewordscloud.models.list_level_update import ListLevelUpdate
from asposewordscloud.models.list_response import ListResponse
from asposewordscloud.models.lists import Lists
from asposewordscloud.models.lists_response import ListsResponse
from asposewordscloud.models.list_update import ListUpdate
from asposewordscloud.models.load_web_document_data import LoadWebDocumentData
from asposewordscloud.models.markdown_save_options_data import MarkdownSaveOptionsData
from asposewordscloud.models.metafile_rendering_options_data import MetafileRenderingOptionsData
from asposewordscloud.models.mhtml_save_options_data import MhtmlSaveOptionsData
from asposewordscloud.models.modification_operation_result import ModificationOperationResult
from asposewordscloud.models.node_link import NodeLink
from asposewordscloud.models.odt_save_options_data import OdtSaveOptionsData
from asposewordscloud.models.office_math_link import OfficeMathLink
from asposewordscloud.models.office_math_object import OfficeMathObject
from asposewordscloud.models.office_math_object_response import OfficeMathObjectResponse
from asposewordscloud.models.office_math_objects_collection import OfficeMathObjectsCollection
from asposewordscloud.models.office_math_objects_response import OfficeMathObjectsResponse
from asposewordscloud.models.open_xps_save_options_data import OpenXpsSaveOptionsData
from asposewordscloud.models.optimization_options import OptimizationOptions
from asposewordscloud.models.ott_save_options_data import OttSaveOptionsData
from asposewordscloud.models.outline_options_data import OutlineOptionsData
from asposewordscloud.models.page_number import PageNumber
from asposewordscloud.models.page_setup import PageSetup
from asposewordscloud.models.page_stat_data import PageStatData
from asposewordscloud.models.paragraph import Paragraph
from asposewordscloud.models.paragraph_format import ParagraphFormat
from asposewordscloud.models.paragraph_format_response import ParagraphFormatResponse
from asposewordscloud.models.paragraph_format_update import ParagraphFormatUpdate
from asposewordscloud.models.paragraph_insert import ParagraphInsert
from asposewordscloud.models.paragraph_link import ParagraphLink
from asposewordscloud.models.paragraph_link_collection import ParagraphLinkCollection
from asposewordscloud.models.paragraph_link_collection_response import ParagraphLinkCollectionResponse
from asposewordscloud.models.paragraph_list_format_response import ParagraphListFormatResponse
from asposewordscloud.models.paragraph_response import ParagraphResponse
from asposewordscloud.models.pcl_save_options_data import PclSaveOptionsData
from asposewordscloud.models.pdf_digital_signature_details_data import PdfDigitalSignatureDetailsData
from asposewordscloud.models.pdf_encryption_details_data import PdfEncryptionDetailsData
from asposewordscloud.models.pdf_permissions import PdfPermissions
from asposewordscloud.models.pdf_save_options_data import PdfSaveOptionsData
from asposewordscloud.models.png_save_options_data import PngSaveOptionsData
from asposewordscloud.models.position_after_node import PositionAfterNode
from asposewordscloud.models.position_before_node import PositionBeforeNode
from asposewordscloud.models.position_inside_node import PositionInsideNode
from asposewordscloud.models.preferred_width import PreferredWidth
from asposewordscloud.models.protection_data import ProtectionData
from asposewordscloud.models.protection_data_response import ProtectionDataResponse
from asposewordscloud.models.protection_request import ProtectionRequest
from asposewordscloud.models.protection_request_v2 import ProtectionRequestV2
from asposewordscloud.models.ps_save_options_data import PsSaveOptionsData
from asposewordscloud.models.public_key_response import PublicKeyResponse
from asposewordscloud.models.range_document import RangeDocument
from asposewordscloud.models.range_text_response import RangeTextResponse
from asposewordscloud.models.replace_range import ReplaceRange
from asposewordscloud.models.replace_text_parameters import ReplaceTextParameters
from asposewordscloud.models.replace_text_response import ReplaceTextResponse
from asposewordscloud.models.report_build_options import ReportBuildOptions
from asposewordscloud.models.report_engine_settings import ReportEngineSettings
from asposewordscloud.models.revision import Revision
from asposewordscloud.models.revision_collection import RevisionCollection
from asposewordscloud.models.revisions_modification_response import RevisionsModificationResponse
from asposewordscloud.models.revisions_response import RevisionsResponse
from asposewordscloud.models.rtf_save_options_data import RtfSaveOptionsData
from asposewordscloud.models.run import Run
from asposewordscloud.models.run_insert import RunInsert
from asposewordscloud.models.run_link import RunLink
from asposewordscloud.models.run_response import RunResponse
from asposewordscloud.models.runs import Runs
from asposewordscloud.models.runs_response import RunsResponse
from asposewordscloud.models.run_update import RunUpdate
from asposewordscloud.models.save_response import SaveResponse
from asposewordscloud.models.save_result import SaveResult
from asposewordscloud.models.search_response import SearchResponse
from asposewordscloud.models.search_result import SearchResult
from asposewordscloud.models.search_results_collection import SearchResultsCollection
from asposewordscloud.models.section import Section
from asposewordscloud.models.section_link import SectionLink
from asposewordscloud.models.section_link_collection import SectionLinkCollection
from asposewordscloud.models.section_link_collection_response import SectionLinkCollectionResponse
from asposewordscloud.models.section_page_setup_response import SectionPageSetupResponse
from asposewordscloud.models.section_response import SectionResponse
from asposewordscloud.models.shading import Shading
from asposewordscloud.models.signature import Signature
from asposewordscloud.models.signature_collection_response import SignatureCollectionResponse
from asposewordscloud.models.sign_options import SignOptions
from asposewordscloud.models.split_document_response import SplitDocumentResponse
from asposewordscloud.models.split_document_result import SplitDocumentResult
from asposewordscloud.models.stat_data_response import StatDataResponse
from asposewordscloud.models.storage_file import StorageFile
from asposewordscloud.models.story_child_nodes import StoryChildNodes
from asposewordscloud.models.structured_document_tag import StructuredDocumentTag
from asposewordscloud.models.structured_document_tag_collection import StructuredDocumentTagCollection
from asposewordscloud.models.structured_document_tag_insert import StructuredDocumentTagInsert
from asposewordscloud.models.structured_document_tag_list_item import StructuredDocumentTagListItem
from asposewordscloud.models.structured_document_tag_response import StructuredDocumentTagResponse
from asposewordscloud.models.structured_document_tags_response import StructuredDocumentTagsResponse
from asposewordscloud.models.structured_document_tag_update import StructuredDocumentTagUpdate
from asposewordscloud.models.style import Style
from asposewordscloud.models.style_apply import StyleApply
from asposewordscloud.models.style_copy import StyleCopy
from asposewordscloud.models.style_insert import StyleInsert
from asposewordscloud.models.style_response import StyleResponse
from asposewordscloud.models.styles_response import StylesResponse
from asposewordscloud.models.style_update import StyleUpdate
from asposewordscloud.models.svg_save_options_data import SvgSaveOptionsData
from asposewordscloud.models.table import Table
from asposewordscloud.models.table_cell import TableCell
from asposewordscloud.models.table_cell_format import TableCellFormat
from asposewordscloud.models.table_cell_format_response import TableCellFormatResponse
from asposewordscloud.models.table_cell_insert import TableCellInsert
from asposewordscloud.models.table_cell_response import TableCellResponse
from asposewordscloud.models.table_insert import TableInsert
from asposewordscloud.models.table_link import TableLink
from asposewordscloud.models.table_link_collection import TableLinkCollection
from asposewordscloud.models.table_link_collection_response import TableLinkCollectionResponse
from asposewordscloud.models.table_properties import TableProperties
from asposewordscloud.models.table_properties_response import TablePropertiesResponse
from asposewordscloud.models.table_response import TableResponse
from asposewordscloud.models.table_row import TableRow
from asposewordscloud.models.table_row_format import TableRowFormat
from asposewordscloud.models.table_row_format_response import TableRowFormatResponse
from asposewordscloud.models.table_row_insert import TableRowInsert
from asposewordscloud.models.table_row_response import TableRowResponse
from asposewordscloud.models.tab_stop import TabStop
from asposewordscloud.models.tab_stop_insert import TabStopInsert
from asposewordscloud.models.tab_stops_response import TabStopsResponse
from asposewordscloud.models.text_save_options_data import TextSaveOptionsData
from asposewordscloud.models.tiff_save_options_data import TiffSaveOptionsData
from asposewordscloud.models.time_zone_info_data import TimeZoneInfoData
from asposewordscloud.models.translate_node_id_response import TranslateNodeIdResponse
from asposewordscloud.models.user_information import UserInformation
from asposewordscloud.models.watermark_data_image import WatermarkDataImage
from asposewordscloud.models.watermark_data_text import WatermarkDataText
from asposewordscloud.models.watermark_text import WatermarkText
from asposewordscloud.models.word_ml_save_options_data import WordMLSaveOptionsData
from asposewordscloud.models.words_api_error_response import WordsApiErrorResponse
from asposewordscloud.models.words_api_link import WordsApiLink
from asposewordscloud.models.words_response import WordsResponse
from asposewordscloud.models.xaml_fixed_save_options_data import XamlFixedSaveOptionsData
from asposewordscloud.models.xaml_flow_pack_save_options_data import XamlFlowPackSaveOptionsData
from asposewordscloud.models.xaml_flow_save_options_data import XamlFlowSaveOptionsData
from asposewordscloud.models.xml_color import XmlColor
from asposewordscloud.models.xml_data_load_options import XmlDataLoadOptions
from asposewordscloud.models.xps_save_options_data import XpsSaveOptionsData



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="downsample_options_data.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class DownsampleOptionsData(object):
    """Container class for Downsample options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'downsample_images': 'bool',
        'resolution': 'int',
        'resolution_threshold': 'int'
    }

    attribute_map = {
        'downsample_images': 'DownsampleImages',
        'resolution': 'Resolution',
        'resolution_threshold': 'ResolutionThreshold'
    }

    def __init__(self, downsample_images=None, resolution=None, resolution_threshold=None):  # noqa: E501
        """DownsampleOptionsData - a model defined in Swagger"""  # noqa: E501

        self._downsample_images = None
        self._resolution = None
        self._resolution_threshold = None
        self.discriminator = None

        if downsample_images is not None:
            self.downsample_images = downsample_images
        if resolution is not None:
            self.resolution = resolution
        if resolution_threshold is not None:
            self.resolution_threshold = resolution_threshold

    @property
    def downsample_images(self):
        """Gets the downsample_images of this DownsampleOptionsData.  # noqa: E501

        Gets or sets a value indicating whether images should be downsampled. The default value is true.  # noqa: E501

        :return: The downsample_images of this DownsampleOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._downsample_images

    @downsample_images.setter
    def downsample_images(self, downsample_images):
        """Sets the downsample_images of this DownsampleOptionsData.

        Gets or sets a value indicating whether images should be downsampled. The default value is true.  # noqa: E501

        :param downsample_images: The downsample_images of this DownsampleOptionsData.  # noqa: E501
        :type: bool
        """
        self._downsample_images = downsample_images

    @property
    def resolution(self):
        """Gets the resolution of this DownsampleOptionsData.  # noqa: E501

        Gets or sets the resolution in pixels per inch which the images should be downsampled to. The default value is 220 ppi.  # noqa: E501

        :return: The resolution of this DownsampleOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """Sets the resolution of this DownsampleOptionsData.

        Gets or sets the resolution in pixels per inch which the images should be downsampled to. The default value is 220 ppi.  # noqa: E501

        :param resolution: The resolution of this DownsampleOptionsData.  # noqa: E501
        :type: int
        """
        self._resolution = resolution

    @property
    def resolution_threshold(self):
        """Gets the resolution_threshold of this DownsampleOptionsData.  # noqa: E501

        Gets or sets the threshold resolution in pixels per inch. If resolution of an image in the document is less than threshold value, the downsampling algorithm will not be applied. A value of 0 means the threshold check is not used and all images that can be reduced in size are downsampled. The default value is 0.  # noqa: E501

        :return: The resolution_threshold of this DownsampleOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._resolution_threshold

    @resolution_threshold.setter
    def resolution_threshold(self, resolution_threshold):
        """Sets the resolution_threshold of this DownsampleOptionsData.

        Gets or sets the threshold resolution in pixels per inch. If resolution of an image in the document is less than threshold value, the downsampling algorithm will not be applied. A value of 0 means the threshold check is not used and all images that can be reduced in size are downsampled. The default value is 0.  # noqa: E501

        :param resolution_threshold: The resolution_threshold of this DownsampleOptionsData.  # noqa: E501
        :type: int
        """
        self._resolution_threshold = resolution_threshold


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DownsampleOptionsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="sign_options.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class SignOptions(object):
    """Container class for digital signature options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comments': 'str',
        'decryption_password': 'str',
        'provider_id': 'str',
        'signature_line_id': 'str',
        'signature_line_image_filename': 'str',
        'sign_time': 'datetime'
    }

    attribute_map = {
        'comments': 'Comments',
        'decryption_password': 'DecryptionPassword',
        'provider_id': 'ProviderId',
        'signature_line_id': 'SignatureLineId',
        'signature_line_image_filename': 'SignatureLineImageFilename',
        'sign_time': 'SignTime'
    }

    def __init__(self, comments=None, decryption_password=None, provider_id=None, signature_line_id=None, signature_line_image_filename=None, sign_time=None):  # noqa: E501
        """SignOptions - a model defined in Swagger"""  # noqa: E501

        self._comments = None
        self._decryption_password = None
        self._provider_id = None
        self._signature_line_id = None
        self._signature_line_image_filename = None
        self._sign_time = None
        self.discriminator = None

        if comments is not None:
            self.comments = comments
        if decryption_password is not None:
            self.decryption_password = decryption_password
        if provider_id is not None:
            self.provider_id = provider_id
        if signature_line_id is not None:
            self.signature_line_id = signature_line_id
        if signature_line_image_filename is not None:
            self.signature_line_image_filename = signature_line_image_filename
        if sign_time is not None:
            self.sign_time = sign_time

    @property
    def comments(self):
        """Gets the comments of this SignOptions.  # noqa: E501

        Gets or sets comments on the digital signature. Default value is empty string.  # noqa: E501

        :return: The comments of this SignOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this SignOptions.

        Gets or sets comments on the digital signature. Default value is empty string.  # noqa: E501

        :param comments: The comments of this SignOptions.  # noqa: E501
        :type: str
        """
        self._comments = comments

    @property
    def decryption_password(self):
        """Gets the decryption_password of this SignOptions.  # noqa: E501

        Gets or sets the password to decrypt source document. Default value is empty string.  # noqa: E501

        :return: The decryption_password of this SignOptions.  # noqa: E501
        :rtype: str
        """
        return self._decryption_password

    @decryption_password.setter
    def decryption_password(self, decryption_password):
        """Sets the decryption_password of this SignOptions.

        Gets or sets the password to decrypt source document. Default value is empty string.  # noqa: E501

        :param decryption_password: The decryption_password of this SignOptions.  # noqa: E501
        :type: str
        """
        self._decryption_password = decryption_password

    @property
    def provider_id(self):
        """Gets the provider_id of this SignOptions.  # noqa: E501

        Gets or sets the class Guid of the signature cryptography provider. Default value is Empty (all zeroes) Guid.  # noqa: E501

        :return: The provider_id of this SignOptions.  # noqa: E501
        :rtype: str
        """
        return self._provider_id

    @provider_id.setter
    def provider_id(self, provider_id):
        """Sets the provider_id of this SignOptions.

        Gets or sets the class Guid of the signature cryptography provider. Default value is Empty (all zeroes) Guid.  # noqa: E501

        :param provider_id: The provider_id of this SignOptions.  # noqa: E501
        :type: str
        """
        self._provider_id = provider_id

    @property
    def signature_line_id(self):
        """Gets the signature_line_id of this SignOptions.  # noqa: E501

        Gets or sets user defined signature line Guid. Default value is Empty (all zeroes) Guid.  # noqa: E501

        :return: The signature_line_id of this SignOptions.  # noqa: E501
        :rtype: str
        """
        return self._signature_line_id

    @signature_line_id.setter
    def signature_line_id(self, signature_line_id):
        """Sets the signature_line_id of this SignOptions.

        Gets or sets user defined signature line Guid. Default value is Empty (all zeroes) Guid.  # noqa: E501

        :param signature_line_id: The signature_line_id of this SignOptions.  # noqa: E501
        :type: str
        """
        self._signature_line_id = signature_line_id

    @property
    def signature_line_image_filename(self):
        """Gets the signature_line_image_filename of this SignOptions.  # noqa: E501

        Gets or sets the image that will be shown in associated SignatureLine. Default value is empty string.  # noqa: E501

        :return: The signature_line_image_filename of this SignOptions.  # noqa: E501
        :rtype: str
        """
        return self._signature_line_image_filename

    @signature_line_image_filename.setter
    def signature_line_image_filename(self, signature_line_image_filename):
        """Sets the signature_line_image_filename of this SignOptions.

        Gets or sets the image that will be shown in associated SignatureLine. Default value is empty string.  # noqa: E501

        :param signature_line_image_filename: The signature_line_image_filename of this SignOptions.  # noqa: E501
        :type: str
        """
        self._signature_line_image_filename = signature_line_image_filename

    @property
    def sign_time(self):
        """Gets the sign_time of this SignOptions.  # noqa: E501

        Gets or sets the date of signing. Default value is current time (Now).  # noqa: E501

        :return: The sign_time of this SignOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._sign_time

    @sign_time.setter
    def sign_time(self, sign_time):
        """Sets the sign_time of this SignOptions.

        Gets or sets the date of signing. Default value is current time (Now).  # noqa: E501

        :param sign_time: The sign_time of this SignOptions.  # noqa: E501
        :type: datetime
        """
        self._sign_time = sign_time


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="paragraph_format.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class ParagraphFormat(object):
    """Paragraph format element.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'add_space_between_far_east_and_alpha': 'bool',
        'add_space_between_far_east_and_digit': 'bool',
        'alignment': 'str',
        'bidi': 'bool',
        'drop_cap_position': 'str',
        'first_line_indent': 'float',
        'keep_together': 'bool',
        'keep_with_next': 'bool',
        'left_indent': 'float',
        'line_spacing': 'float',
        'line_spacing_rule': 'str',
        'lines_to_drop': 'int',
        'no_space_between_paragraphs_of_same_style': 'bool',
        'outline_level': 'str',
        'page_break_before': 'bool',
        'right_indent': 'float',
        'space_after': 'float',
        'space_after_auto': 'bool',
        'space_before': 'float',
        'space_before_auto': 'bool',
        'style_identifier': 'str',
        'style_name': 'str',
        'suppress_auto_hyphens': 'bool',
        'suppress_line_numbers': 'bool',
        'widow_control': 'bool',
        'shading': 'Shading',
        'is_list_item': 'bool',
        'is_heading': 'bool'
    }

    attribute_map = {
        'link': 'Link',
        'add_space_between_far_east_and_alpha': 'AddSpaceBetweenFarEastAndAlpha',
        'add_space_between_far_east_and_digit': 'AddSpaceBetweenFarEastAndDigit',
        'alignment': 'Alignment',
        'bidi': 'Bidi',
        'drop_cap_position': 'DropCapPosition',
        'first_line_indent': 'FirstLineIndent',
        'keep_together': 'KeepTogether',
        'keep_with_next': 'KeepWithNext',
        'left_indent': 'LeftIndent',
        'line_spacing': 'LineSpacing',
        'line_spacing_rule': 'LineSpacingRule',
        'lines_to_drop': 'LinesToDrop',
        'no_space_between_paragraphs_of_same_style': 'NoSpaceBetweenParagraphsOfSameStyle',
        'outline_level': 'OutlineLevel',
        'page_break_before': 'PageBreakBefore',
        'right_indent': 'RightIndent',
        'space_after': 'SpaceAfter',
        'space_after_auto': 'SpaceAfterAuto',
        'space_before': 'SpaceBefore',
        'space_before_auto': 'SpaceBeforeAuto',
        'style_identifier': 'StyleIdentifier',
        'style_name': 'StyleName',
        'suppress_auto_hyphens': 'SuppressAutoHyphens',
        'suppress_line_numbers': 'SuppressLineNumbers',
        'widow_control': 'WidowControl',
        'shading': 'Shading',
        'is_list_item': 'IsListItem',
        'is_heading': 'IsHeading'
    }

    def __init__(self, link=None, add_space_between_far_east_and_alpha=None, add_space_between_far_east_and_digit=None, alignment=None, bidi=None, drop_cap_position=None, first_line_indent=None, keep_together=None, keep_with_next=None, left_indent=None, line_spacing=None, line_spacing_rule=None, lines_to_drop=None, no_space_between_paragraphs_of_same_style=None, outline_level=None, page_break_before=None, right_indent=None, space_after=None, space_after_auto=None, space_before=None, space_before_auto=None, style_identifier=None, style_name=None, suppress_auto_hyphens=None, suppress_line_numbers=None, widow_control=None, shading=None, is_list_item=None, is_heading=None):  # noqa: E501
        """ParagraphFormat - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._add_space_between_far_east_and_alpha = None
        self._add_space_between_far_east_and_digit = None
        self._alignment = None
        self._bidi = None
        self._drop_cap_position = None
        self._first_line_indent = None
        self._keep_together = None
        self._keep_with_next = None
        self._left_indent = None
        self._line_spacing = None
        self._line_spacing_rule = None
        self._lines_to_drop = None
        self._no_space_between_paragraphs_of_same_style = None
        self._outline_level = None
        self._page_break_before = None
        self._right_indent = None
        self._space_after = None
        self._space_after_auto = None
        self._space_before = None
        self._space_before_auto = None
        self._style_identifier = None
        self._style_name = None
        self._suppress_auto_hyphens = None
        self._suppress_line_numbers = None
        self._widow_control = None
        self._shading = None
        self._is_list_item = None
        self._is_heading = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if add_space_between_far_east_and_alpha is not None:
            self.add_space_between_far_east_and_alpha = add_space_between_far_east_and_alpha
        if add_space_between_far_east_and_digit is not None:
            self.add_space_between_far_east_and_digit = add_space_between_far_east_and_digit
        if alignment is not None:
            self.alignment = alignment
        if bidi is not None:
            self.bidi = bidi
        if drop_cap_position is not None:
            self.drop_cap_position = drop_cap_position
        if first_line_indent is not None:
            self.first_line_indent = first_line_indent
        if keep_together is not None:
            self.keep_together = keep_together
        if keep_with_next is not None:
            self.keep_with_next = keep_with_next
        if left_indent is not None:
            self.left_indent = left_indent
        if line_spacing is not None:
            self.line_spacing = line_spacing
        if line_spacing_rule is not None:
            self.line_spacing_rule = line_spacing_rule
        if lines_to_drop is not None:
            self.lines_to_drop = lines_to_drop
        if no_space_between_paragraphs_of_same_style is not None:
            self.no_space_between_paragraphs_of_same_style = no_space_between_paragraphs_of_same_style
        if outline_level is not None:
            self.outline_level = outline_level
        if page_break_before is not None:
            self.page_break_before = page_break_before
        if right_indent is not None:
            self.right_indent = right_indent
        if space_after is not None:
            self.space_after = space_after
        if space_after_auto is not None:
            self.space_after_auto = space_after_auto
        if space_before is not None:
            self.space_before = space_before
        if space_before_auto is not None:
            self.space_before_auto = space_before_auto
        if style_identifier is not None:
            self.style_identifier = style_identifier
        if style_name is not None:
            self.style_name = style_name
        if suppress_auto_hyphens is not None:
            self.suppress_auto_hyphens = suppress_auto_hyphens
        if suppress_line_numbers is not None:
            self.suppress_line_numbers = suppress_line_numbers
        if widow_control is not None:
            self.widow_control = widow_control
        if shading is not None:
            self.shading = shading
        if is_list_item is not None:
            self.is_list_item = is_list_item
        if is_heading is not None:
            self.is_heading = is_heading

    @property
    def link(self):
        """Gets the link of this ParagraphFormat.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this ParagraphFormat.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this ParagraphFormat.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this ParagraphFormat.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def add_space_between_far_east_and_alpha(self):
        """Gets the add_space_between_far_east_and_alpha of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether inter-character spacing is automatically adjusted between regions of Latin text and regions of East Asian text in the current paragraph.  # noqa: E501

        :return: The add_space_between_far_east_and_alpha of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._add_space_between_far_east_and_alpha

    @add_space_between_far_east_and_alpha.setter
    def add_space_between_far_east_and_alpha(self, add_space_between_far_east_and_alpha):
        """Sets the add_space_between_far_east_and_alpha of this ParagraphFormat.

        Gets or sets a value indicating whether inter-character spacing is automatically adjusted between regions of Latin text and regions of East Asian text in the current paragraph.  # noqa: E501

        :param add_space_between_far_east_and_alpha: The add_space_between_far_east_and_alpha of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._add_space_between_far_east_and_alpha = add_space_between_far_east_and_alpha

    @property
    def add_space_between_far_east_and_digit(self):
        """Gets the add_space_between_far_east_and_digit of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether inter-character spacing is automatically adjusted between regions of numbers and regions of East Asian text in the current paragraph.  # noqa: E501

        :return: The add_space_between_far_east_and_digit of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._add_space_between_far_east_and_digit

    @add_space_between_far_east_and_digit.setter
    def add_space_between_far_east_and_digit(self, add_space_between_far_east_and_digit):
        """Sets the add_space_between_far_east_and_digit of this ParagraphFormat.

        Gets or sets a value indicating whether inter-character spacing is automatically adjusted between regions of numbers and regions of East Asian text in the current paragraph.  # noqa: E501

        :param add_space_between_far_east_and_digit: The add_space_between_far_east_and_digit of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._add_space_between_far_east_and_digit = add_space_between_far_east_and_digit

    @property
    def alignment(self):
        """Gets the alignment of this ParagraphFormat.  # noqa: E501

        Gets or sets text alignment for the paragraph.  # noqa: E501

        :return: The alignment of this ParagraphFormat.  # noqa: E501
        :rtype: str
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """Sets the alignment of this ParagraphFormat.

        Gets or sets text alignment for the paragraph.  # noqa: E501

        :param alignment: The alignment of this ParagraphFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["Left", "Center", "Right", "Justify", "Distributed", "ArabicMediumKashida", "ArabicHighKashida", "ArabicLowKashida", "ThaiDistributed", "MathElementCenterAsGroup"]  # noqa: E501
        if not alignment.isdigit():
            if alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(alignment, allowed_values))
            self._alignment = alignment
        else:
            self._alignment = allowed_values[int(alignment) if six.PY3 else long(alignment)]

    @property
    def bidi(self):
        """Gets the bidi of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether this is a right-to-left paragraph. When true, the runs and other inline objects in this paragraph are laid out right to left.  # noqa: E501

        :return: The bidi of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._bidi

    @bidi.setter
    def bidi(self, bidi):
        """Sets the bidi of this ParagraphFormat.

        Gets or sets a value indicating whether this is a right-to-left paragraph. When true, the runs and other inline objects in this paragraph are laid out right to left.  # noqa: E501

        :param bidi: The bidi of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._bidi = bidi

    @property
    def drop_cap_position(self):
        """Gets the drop_cap_position of this ParagraphFormat.  # noqa: E501

        Gets or sets the position for a drop cap text.  # noqa: E501

        :return: The drop_cap_position of this ParagraphFormat.  # noqa: E501
        :rtype: str
        """
        return self._drop_cap_position

    @drop_cap_position.setter
    def drop_cap_position(self, drop_cap_position):
        """Sets the drop_cap_position of this ParagraphFormat.

        Gets or sets the position for a drop cap text.  # noqa: E501

        :param drop_cap_position: The drop_cap_position of this ParagraphFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Normal", "Margin"]  # noqa: E501
        if not drop_cap_position.isdigit():
            if drop_cap_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `drop_cap_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(drop_cap_position, allowed_values))
            self._drop_cap_position = drop_cap_position
        else:
            self._drop_cap_position = allowed_values[int(drop_cap_position) if six.PY3 else long(drop_cap_position)]

    @property
    def first_line_indent(self):
        """Gets the first_line_indent of this ParagraphFormat.  # noqa: E501

        Gets or sets the value (in points) for a first line or hanging indent. Use a positive value to set a first-line indent, and use a negative value to set a hanging indent.  # noqa: E501

        :return: The first_line_indent of this ParagraphFormat.  # noqa: E501
        :rtype: float
        """
        return self._first_line_indent

    @first_line_indent.setter
    def first_line_indent(self, first_line_indent):
        """Sets the first_line_indent of this ParagraphFormat.

        Gets or sets the value (in points) for a first line or hanging indent. Use a positive value to set a first-line indent, and use a negative value to set a hanging indent.  # noqa: E501

        :param first_line_indent: The first_line_indent of this ParagraphFormat.  # noqa: E501
        :type: float
        """
        self._first_line_indent = first_line_indent

    @property
    def keep_together(self):
        """Gets the keep_together of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether all lines in the paragraph are to remain on the same page.  # noqa: E501

        :return: The keep_together of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._keep_together

    @keep_together.setter
    def keep_together(self, keep_together):
        """Sets the keep_together of this ParagraphFormat.

        Gets or sets a value indicating whether all lines in the paragraph are to remain on the same page.  # noqa: E501

        :param keep_together: The keep_together of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._keep_together = keep_together

    @property
    def keep_with_next(self):
        """Gets the keep_with_next of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the paragraph is to remains on the same page as the paragraph that follows it.  # noqa: E501

        :return: The keep_with_next of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._keep_with_next

    @keep_with_next.setter
    def keep_with_next(self, keep_with_next):
        """Sets the keep_with_next of this ParagraphFormat.

        Gets or sets a value indicating whether the paragraph is to remains on the same page as the paragraph that follows it.  # noqa: E501

        :param keep_with_next: The keep_with_next of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._keep_with_next = keep_with_next

    @property
    def left_indent(self):
        """Gets the left_indent of this ParagraphFormat.  # noqa: E501

        Gets or sets the value (in points), that represents the left indent for paragraph.  # noqa: E501

        :return: The left_indent of this ParagraphFormat.  # noqa: E501
        :rtype: float
        """
        return self._left_indent

    @left_indent.setter
    def left_indent(self, left_indent):
        """Sets the left_indent of this ParagraphFormat.

        Gets or sets the value (in points), that represents the left indent for paragraph.  # noqa: E501

        :param left_indent: The left_indent of this ParagraphFormat.  # noqa: E501
        :type: float
        """
        self._left_indent = left_indent

    @property
    def line_spacing(self):
        """Gets the line_spacing of this ParagraphFormat.  # noqa: E501

        Gets or sets the line spacing (in points) for the paragraph. When LineSpacingRule property is set to AtLeast, the line spacing can be greater than or equal to, but never less than the specified LineSpacing value.When LineSpacingRule property is set to Exactly, the line spacing never changes from the specified LineSpacing value, even if a larger font is used within the paragraph.  # noqa: E501

        :return: The line_spacing of this ParagraphFormat.  # noqa: E501
        :rtype: float
        """
        return self._line_spacing

    @line_spacing.setter
    def line_spacing(self, line_spacing):
        """Sets the line_spacing of this ParagraphFormat.

        Gets or sets the line spacing (in points) for the paragraph. When LineSpacingRule property is set to AtLeast, the line spacing can be greater than or equal to, but never less than the specified LineSpacing value.When LineSpacingRule property is set to Exactly, the line spacing never changes from the specified LineSpacing value, even if a larger font is used within the paragraph.  # noqa: E501

        :param line_spacing: The line_spacing of this ParagraphFormat.  # noqa: E501
        :type: float
        """
        self._line_spacing = line_spacing

    @property
    def line_spacing_rule(self):
        """Gets the line_spacing_rule of this ParagraphFormat.  # noqa: E501

        Gets or sets the line spacing for the paragraph.  # noqa: E501

        :return: The line_spacing_rule of this ParagraphFormat.  # noqa: E501
        :rtype: str
        """
        return self._line_spacing_rule

    @line_spacing_rule.setter
    def line_spacing_rule(self, line_spacing_rule):
        """Sets the line_spacing_rule of this ParagraphFormat.

        Gets or sets the line spacing for the paragraph.  # noqa: E501

        :param line_spacing_rule: The line_spacing_rule of this ParagraphFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["AtLeast", "Exactly", "Multiple"]  # noqa: E501
        if not line_spacing_rule.isdigit():
            if line_spacing_rule not in allowed_values:
                raise ValueError(
                    "Invalid value for `line_spacing_rule` ({0}), must be one of {1}"  # noqa: E501
                    .format(line_spacing_rule, allowed_values))
            self._line_spacing_rule = line_spacing_rule
        else:
            self._line_spacing_rule = allowed_values[int(line_spacing_rule) if six.PY3 else long(line_spacing_rule)]

    @property
    def lines_to_drop(self):
        """Gets the lines_to_drop of this ParagraphFormat.  # noqa: E501

        Gets or sets the number of lines of the paragraph text used to calculate the drop cap height.  # noqa: E501

        :return: The lines_to_drop of this ParagraphFormat.  # noqa: E501
        :rtype: int
        """
        return self._lines_to_drop

    @lines_to_drop.setter
    def lines_to_drop(self, lines_to_drop):
        """Sets the lines_to_drop of this ParagraphFormat.

        Gets or sets the number of lines of the paragraph text used to calculate the drop cap height.  # noqa: E501

        :param lines_to_drop: The lines_to_drop of this ParagraphFormat.  # noqa: E501
        :type: int
        """
        self._lines_to_drop = lines_to_drop

    @property
    def no_space_between_paragraphs_of_same_style(self):
        """Gets the no_space_between_paragraphs_of_same_style of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether SpaceBefore and SpaceAfter will be ignored between the paragraphs of the same style. This setting only takes affect when applied to a paragraph style. If applied to a paragraph directly, it has no effect.  # noqa: E501

        :return: The no_space_between_paragraphs_of_same_style of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._no_space_between_paragraphs_of_same_style

    @no_space_between_paragraphs_of_same_style.setter
    def no_space_between_paragraphs_of_same_style(self, no_space_between_paragraphs_of_same_style):
        """Sets the no_space_between_paragraphs_of_same_style of this ParagraphFormat.

        Gets or sets a value indicating whether SpaceBefore and SpaceAfter will be ignored between the paragraphs of the same style. This setting only takes affect when applied to a paragraph style. If applied to a paragraph directly, it has no effect.  # noqa: E501

        :param no_space_between_paragraphs_of_same_style: The no_space_between_paragraphs_of_same_style of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._no_space_between_paragraphs_of_same_style = no_space_between_paragraphs_of_same_style

    @property
    def outline_level(self):
        """Gets the outline_level of this ParagraphFormat.  # noqa: E501

        Gets or sets the outline level of the paragraph in the document.  # noqa: E501

        :return: The outline_level of this ParagraphFormat.  # noqa: E501
        :rtype: str
        """
        return self._outline_level

    @outline_level.setter
    def outline_level(self, outline_level):
        """Sets the outline_level of this ParagraphFormat.

        Gets or sets the outline level of the paragraph in the document.  # noqa: E501

        :param outline_level: The outline_level of this ParagraphFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["Level1", "Level2", "Level3", "Level4", "Level5", "Level6", "Level7", "Level8", "Level9", "BodyText"]  # noqa: E501
        if not outline_level.isdigit():
            if outline_level not in allowed_values:
                raise ValueError(
                    "Invalid value for `outline_level` ({0}), must be one of {1}"  # noqa: E501
                    .format(outline_level, allowed_values))
            self._outline_level = outline_level
        else:
            self._outline_level = allowed_values[int(outline_level) if six.PY3 else long(outline_level)]

    @property
    def page_break_before(self):
        """Gets the page_break_before of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether a page break is forced before the paragraph.  # noqa: E501

        :return: The page_break_before of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._page_break_before

    @page_break_before.setter
    def page_break_before(self, page_break_before):
        """Sets the page_break_before of this ParagraphFormat.

        Gets or sets a value indicating whether a page break is forced before the paragraph.  # noqa: E501

        :param page_break_before: The page_break_before of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._page_break_before = page_break_before

    @property
    def right_indent(self):
        """Gets the right_indent of this ParagraphFormat.  # noqa: E501

        Gets or sets the value (in points) that represents the right indent for paragraph.  # noqa: E501

        :return: The right_indent of this ParagraphFormat.  # noqa: E501
        :rtype: float
        """
        return self._right_indent

    @right_indent.setter
    def right_indent(self, right_indent):
        """Sets the right_indent of this ParagraphFormat.

        Gets or sets the value (in points) that represents the right indent for paragraph.  # noqa: E501

        :param right_indent: The right_indent of this ParagraphFormat.  # noqa: E501
        :type: float
        """
        self._right_indent = right_indent

    @property
    def space_after(self):
        """Gets the space_after of this ParagraphFormat.  # noqa: E501

        Gets or sets the amount of spacing (in points) after the paragraph. Has no effect when SpaceAfterAuto is true.  # noqa: E501

        :return: The space_after of this ParagraphFormat.  # noqa: E501
        :rtype: float
        """
        return self._space_after

    @space_after.setter
    def space_after(self, space_after):
        """Sets the space_after of this ParagraphFormat.

        Gets or sets the amount of spacing (in points) after the paragraph. Has no effect when SpaceAfterAuto is true.  # noqa: E501

        :param space_after: The space_after of this ParagraphFormat.  # noqa: E501
        :type: float
        """
        self._space_after = space_after

    @property
    def space_after_auto(self):
        """Gets the space_after_auto of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the amount of spacing after the paragraph is set automatically. When set to true, overrides the effect of SpaceAfter.  # noqa: E501

        :return: The space_after_auto of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._space_after_auto

    @space_after_auto.setter
    def space_after_auto(self, space_after_auto):
        """Sets the space_after_auto of this ParagraphFormat.

        Gets or sets a value indicating whether the amount of spacing after the paragraph is set automatically. When set to true, overrides the effect of SpaceAfter.  # noqa: E501

        :param space_after_auto: The space_after_auto of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._space_after_auto = space_after_auto

    @property
    def space_before(self):
        """Gets the space_before of this ParagraphFormat.  # noqa: E501

        Gets or sets the amount of spacing (in points) before the paragraph. Has no effect when SpaceBeforeAuto is true.  # noqa: E501

        :return: The space_before of this ParagraphFormat.  # noqa: E501
        :rtype: float
        """
        return self._space_before

    @space_before.setter
    def space_before(self, space_before):
        """Sets the space_before of this ParagraphFormat.

        Gets or sets the amount of spacing (in points) before the paragraph. Has no effect when SpaceBeforeAuto is true.  # noqa: E501

        :param space_before: The space_before of this ParagraphFormat.  # noqa: E501
        :type: float
        """
        self._space_before = space_before

    @property
    def space_before_auto(self):
        """Gets the space_before_auto of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the amount of spacing before the paragraph is set automatically. When set to true, overrides the effect of SpaceBefore.  # noqa: E501

        :return: The space_before_auto of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._space_before_auto

    @space_before_auto.setter
    def space_before_auto(self, space_before_auto):
        """Sets the space_before_auto of this ParagraphFormat.

        Gets or sets a value indicating whether the amount of spacing before the paragraph is set automatically. When set to true, overrides the effect of SpaceBefore.  # noqa: E501

        :param space_before_auto: The space_before_auto of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._space_before_auto = space_before_auto

    @property
    def style_identifier(self):
        """Gets the style_identifier of this ParagraphFormat.  # noqa: E501

        Gets or sets the locale independent style identifier of the paragraph style applied to this formatting.  # noqa: E501

        :return: The style_identifier of this ParagraphFormat.  # noqa: E501
        :rtype: str
        """
        return self._style_identifier

    @style_identifier.setter
    def style_identifier(self, style_identifier):
        """Sets the style_identifier of this ParagraphFormat.

        Gets or sets the locale independent style identifier of the paragraph style applied to this formatting.  # noqa: E501

        :param style_identifier: The style_identifier of this ParagraphFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["Normal", "Heading1", "Heading2", "Heading3", "Heading4", "Heading5", "Heading6", "Heading7", "Heading8", "Heading9", "Index1", "Index2", "Index3", "Index4", "Index5", "Index6", "Index7", "Index8", "Index9", "Toc1", "Toc2", "Toc3", "Toc4", "Toc5", "Toc6", "Toc7", "Toc8", "Toc9", "NormalIndent", "FootnoteText", "CommentText", "Header", "Footer", "IndexHeading", "Caption", "TableOfFigures", "EnvelopeAddress", "EnvelopeReturn", "FootnoteReference", "CommentReference", "LineNumber", "PageNumber", "EndnoteReference", "EndnoteText", "TableOfAuthorities", "Macro", "ToaHeading", "List", "ListBullet", "ListNumber", "List2", "List3", "List4", "List5", "ListBullet2", "ListBullet3", "ListBullet4", "ListBullet5", "ListNumber2", "ListNumber3", "ListNumber4", "ListNumber5", "Title", "Closing", "Signature", "DefaultParagraphFont", "BodyText", "BodyTextInd", "ListContinue", "ListContinue2", "ListContinue3", "ListContinue4", "ListContinue5", "MessageHeader", "Subtitle", "Salutation", "Date", "BodyText1I", "BodyText1I2", "NoteHeading", "BodyText2", "BodyText3", "BodyTextInd2", "BodyTextInd3", "BlockText", "Hyperlink", "FollowedHyperlink", "Strong", "Emphasis", "DocumentMap", "PlainText", "EmailSignature", "HtmlTopOfForm", "HtmlBottomOfForm", "NormalWeb", "HtmlAcronym", "HtmlAddress", "HtmlCite", "HtmlCode", "HtmlDefinition", "HtmlKeyboard", "HtmlPreformatted", "HtmlSample", "HtmlTypewriter", "HtmlVariable", "TableNormal", "CommentSubject", "NoList", "OutlineList1", "OutlineList2", "OutlineList3", "TableSimple1", "TableSimple2", "TableSimple3", "TableClassic1", "TableClassic2", "TableClassic3", "TableClassic4", "TableColorful1", "TableColorful2", "TableColorful3", "TableColumns1", "TableColumns2", "TableColumns3", "TableColumns4", "TableColumns5", "TableGrid1", "TableGrid2", "TableGrid3", "TableGrid4", "TableGrid5", "TableGrid6", "TableGrid7", "TableGrid8", "TableList1", "TableList2", "TableList3", "TableList4", "TableList5", "TableList6", "TableList7", "TableList8", "Table3DEffects1", "Table3DEffects2", "Table3DEffects3", "TableContemporary", "TableElegant", "TableProfessional", "TableSubtle1", "TableSubtle2", "TableWeb1", "TableWeb2", "TableWeb3", "BalloonText", "TableGrid", "TableTheme", "PlaceholderText", "NoSpacing", "LightShading", "LightList", "LightGrid", "MediumShading1", "MediumShading2", "MediumList1", "MediumList2", "MediumGrid1", "MediumGrid2", "MediumGrid3", "DarkList", "ColorfulShading", "ColorfulList", "ColorfulGrid", "LightShadingAccent1", "LightListAccent1", "LightGridAccent1", "MediumShading1Accent1", "MediumShading2Accent1", "MediumList1Accent1", "Revision", "ListParagraph", "Quote", "IntenseQuote", "MediumList2Accent1", "MediumGrid1Accent1", "MediumGrid2Accent1", "MediumGrid3Accent1", "DarkListAccent1", "ColorfulShadingAccent1", "ColorfulListAccent1", "ColorfulGridAccent1", "LightShadingAccent2", "LightListAccent2", "LightGridAccent2", "MediumShading1Accent2", "MediumShading2Accent2", "MediumList1Accent2", "MediumList2Accent2", "MediumGrid1Accent2", "MediumGrid2Accent2", "MediumGrid3Accent2", "DarkListAccent2", "ColorfulShadingAccent2", "ColorfulListAccent2", "ColorfulGridAccent2", "LightShadingAccent3", "LightListAccent3", "LightGridAccent3", "MediumShading1Accent3", "MediumShading2Accent3", "MediumList1Accent3", "MediumList2Accent3", "MediumGrid1Accent3", "MediumGrid2Accent3", "MediumGrid3Accent3", "DarkListAccent3", "ColorfulShadingAccent3", "ColorfulListAccent3", "ColorfulGridAccent3", "LightShadingAccent4", "LightListAccent4", "LightGridAccent4", "MediumShading1Accent4", "MediumShading2Accent4", "MediumList1Accent4", "MediumList2Accent4", "MediumGrid1Accent4", "MediumGrid2Accent4", "MediumGrid3Accent4", "DarkListAccent4", "ColorfulShadingAccent4", "ColorfulListAccent4", "ColorfulGridAccent4", "LightShadingAccent5", "LightListAccent5", "LightGridAccent5", "MediumShading1Accent5", "MediumShading2Accent5", "MediumList1Accent5", "MediumList2Accent5", "MediumGrid1Accent5", "MediumGrid2Accent5", "MediumGrid3Accent5", "DarkListAccent5", "ColorfulShadingAccent5", "ColorfulListAccent5", "ColorfulGridAccent5", "LightShadingAccent6", "LightListAccent6", "LightGridAccent6", "MediumShading1Accent6", "MediumShading2Accent6", "MediumList1Accent6", "MediumList2Accent6", "MediumGrid1Accent6", "MediumGrid2Accent6", "MediumGrid3Accent6", "DarkListAccent6", "ColorfulShadingAccent6", "ColorfulListAccent6", "ColorfulGridAccent6", "SubtleEmphasis", "IntenseEmphasis", "SubtleReference", "IntenseReference", "BookTitle", "Bibliography", "TocHeading", "PlainTable1", "PlainTable2", "PlainTable3", "PlainTable4", "PlainTable5", "TableGridLight", "GridTable1Light", "GridTable2", "GridTable3", "GridTable4", "GridTable5Dark", "GridTable6Colorful", "GridTable7Colorful", "GridTable1LightAccent1", "GridTable2Accent1", "GridTable3Accent1", "GridTable4Accent1", "GridTable5DarkAccent1", "GridTable6ColorfulAccent1", "GridTable7ColorfulAccent1", "GridTable1LightAccent2", "GridTable2Accent2", "GridTable3Accent2", "GridTable4Accent2", "GridTable5DarkAccent2", "GridTable6ColorfulAccent2", "GridTable7ColorfulAccent2", "GridTable1LightAccent3", "GridTable2Accent3", "GridTable3Accent3", "GridTable4Accent3", "GridTable5DarkAccent3", "GridTable6ColorfulAccent3", "GridTable7ColorfulAccent3", "GridTable1LightAccent4", "GridTable2Accent4", "GridTable3Accent4", "GridTable4Accent4", "GridTable5DarkAccent4", "GridTable6ColorfulAccent4", "GridTable7ColorfulAccent4", "GridTable1LightAccent5", "GridTable2Accent5", "GridTable3Accent5", "GridTable4Accent5", "GridTable5DarkAccent5", "GridTable6ColorfulAccent5", "GridTable7ColorfulAccent5", "GridTable1LightAccent6", "GridTable2Accent6", "GridTable3Accent6", "GridTable4Accent6", "GridTable5DarkAccent6", "GridTable6ColorfulAccent6", "GridTable7ColorfulAccent6", "ListTable1Light", "ListTable2", "ListTable3", "ListTable4", "ListTable5Dark", "ListTable6Colorful", "ListTable7Colorful", "ListTable1LightAccent1", "ListTable2Accent1", "ListTable3Accent1", "ListTable4Accent1", "ListTable5DarkAccent1", "ListTable6ColorfulAccent1", "ListTable7ColorfulAccent1", "ListTable1LightAccent2", "ListTable2Accent2", "ListTable3Accent2", "ListTable4Accent2", "ListTable5DarkAccent2", "ListTable6ColorfulAccent2", "ListTable7ColorfulAccent2", "ListTable1LightAccent3", "ListTable2Accent3", "ListTable3Accent3", "ListTable4Accent3", "ListTable5DarkAccent3", "ListTable6ColorfulAccent3", "ListTable7ColorfulAccent3", "ListTable1LightAccent4", "ListTable2Accent4", "ListTable3Accent4", "ListTable4Accent4", "ListTable5DarkAccent4", "ListTable6ColorfulAccent4", "ListTable7ColorfulAccent4", "ListTable1LightAccent5", "ListTable2Accent5", "ListTable3Accent5", "ListTable4Accent5", "ListTable5DarkAccent5", "ListTable6ColorfulAccent5", "ListTable7ColorfulAccent5", "ListTable1LightAccent6", "ListTable2Accent6", "ListTable3Accent6", "ListTable4Accent6", "ListTable5DarkAccent6", "ListTable6ColorfulAccent6", "ListTable7ColorfulAccent6", "SmartLink", "Mention", "SmartHyperlink", "Hashtag", "UnresolvedMention", "User", "Nil"]  # noqa: E501
        if not style_identifier.isdigit():
            if style_identifier not in allowed_values:
                raise ValueError(
                    "Invalid value for `style_identifier` ({0}), must be one of {1}"  # noqa: E501
                    .format(style_identifier, allowed_values))
            self._style_identifier = style_identifier
        else:
            self._style_identifier = allowed_values[int(style_identifier) if six.PY3 else long(style_identifier)]

    @property
    def style_name(self):
        """Gets the style_name of this ParagraphFormat.  # noqa: E501

        Gets or sets the name of the paragraph style applied to this formatting.  # noqa: E501

        :return: The style_name of this ParagraphFormat.  # noqa: E501
        :rtype: str
        """
        return self._style_name

    @style_name.setter
    def style_name(self, style_name):
        """Sets the style_name of this ParagraphFormat.

        Gets or sets the name of the paragraph style applied to this formatting.  # noqa: E501

        :param style_name: The style_name of this ParagraphFormat.  # noqa: E501
        :type: str
        """
        self._style_name = style_name

    @property
    def suppress_auto_hyphens(self):
        """Gets the suppress_auto_hyphens of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the current paragraph should be exempted from any hyphenation which is applied in the document settings.  # noqa: E501

        :return: The suppress_auto_hyphens of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_auto_hyphens

    @suppress_auto_hyphens.setter
    def suppress_auto_hyphens(self, suppress_auto_hyphens):
        """Sets the suppress_auto_hyphens of this ParagraphFormat.

        Gets or sets a value indicating whether the current paragraph should be exempted from any hyphenation which is applied in the document settings.  # noqa: E501

        :param suppress_auto_hyphens: The suppress_auto_hyphens of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._suppress_auto_hyphens = suppress_auto_hyphens

    @property
    def suppress_line_numbers(self):
        """Gets the suppress_line_numbers of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the current paragraph's lines should be exempted from line numbering which is applied in the parent section.  # noqa: E501

        :return: The suppress_line_numbers of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_line_numbers

    @suppress_line_numbers.setter
    def suppress_line_numbers(self, suppress_line_numbers):
        """Sets the suppress_line_numbers of this ParagraphFormat.

        Gets or sets a value indicating whether the current paragraph's lines should be exempted from line numbering which is applied in the parent section.  # noqa: E501

        :param suppress_line_numbers: The suppress_line_numbers of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._suppress_line_numbers = suppress_line_numbers

    @property
    def widow_control(self):
        """Gets the widow_control of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the first and last lines in the paragraph are to remain on the same page as the rest of the paragraph.  # noqa: E501

        :return: The widow_control of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._widow_control

    @widow_control.setter
    def widow_control(self, widow_control):
        """Sets the widow_control of this ParagraphFormat.

        Gets or sets a value indicating whether the first and last lines in the paragraph are to remain on the same page as the rest of the paragraph.  # noqa: E501

        :param widow_control: The widow_control of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._widow_control = widow_control

    @property
    def shading(self):
        """Gets the shading of this ParagraphFormat.  # noqa: E501

        Gets or sets the Shading object, that refers to the shading formatting for the paragraph.  # noqa: E501

        :return: The shading of this ParagraphFormat.  # noqa: E501
        :rtype: Shading
        """
        return self._shading

    @shading.setter
    def shading(self, shading):
        """Sets the shading of this ParagraphFormat.

        Gets or sets the Shading object, that refers to the shading formatting for the paragraph.  # noqa: E501

        :param shading: The shading of this ParagraphFormat.  # noqa: E501
        :type: Shading
        """
        self._shading = shading

    @property
    def is_list_item(self):
        """Gets the is_list_item of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the paragraph is an item in a bulleted or numbered list.  # noqa: E501

        :return: The is_list_item of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._is_list_item

    @is_list_item.setter
    def is_list_item(self, is_list_item):
        """Sets the is_list_item of this ParagraphFormat.

        Gets or sets a value indicating whether the paragraph is an item in a bulleted or numbered list.  # noqa: E501

        :param is_list_item: The is_list_item of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._is_list_item = is_list_item

    @property
    def is_heading(self):
        """Gets the is_heading of this ParagraphFormat.  # noqa: E501

        Gets or sets a value indicating whether the paragraph style is one of the built-in Heading styles.  # noqa: E501

        :return: The is_heading of this ParagraphFormat.  # noqa: E501
        :rtype: bool
        """
        return self._is_heading

    @is_heading.setter
    def is_heading(self, is_heading):
        """Sets the is_heading of this ParagraphFormat.

        Gets or sets a value indicating whether the paragraph style is one of the built-in Heading styles.  # noqa: E501

        :param is_heading: The is_heading of this ParagraphFormat.  # noqa: E501
        :type: bool
        """
        self._is_heading = is_heading


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

        if self._link is not None:
            self._link.validate()




























        if self._shading is not None:
            self._shading.validate()




    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParagraphFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="base_test_context.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import os
import json
import uuid
import unittest
import warnings
import asposewordscloud
import six
import xmlrunner


class BaseTestContext(unittest.TestCase):

    def read_config(self):
        root_path = os.path.abspath(os.path.realpath(os.path.dirname(__file__)) + "/..")
        creds_path = os.path.join(root_path, 'Settings', 'servercreds.json')
        if not os.path.exists(creds_path):
            raise IOError('Credential file Settings/servercreds.json is not found')
        with open(os.path.join(root_path, 'Settings', 'servercreds.json')) as f:
            creds = json.loads(f.read())
        return creds

    def setUp(self):
        root_path = os.path.abspath(os.path.realpath(os.path.dirname(__file__)) + "/..")
        self.local_test_folder = os.path.join(root_path, 'TestData')
        self.remote_test_folder = os.path.join('Temp', 'SdkTests', 'python')
        self.remote_test_out = os.path.join('Temp', 'SdkTests', 'python', 'TestOut')
        self.local_common_folder = os.path.join(self.local_test_folder, 'Common')
        # creds_path = os.path.join(root_path, 'Settings', 'servercreds.json')
        # if not os.path.exists(creds_path):
        #    raise IOError('Credential file Settings/servercreds.json is not found')

        # with open(os.path.join(root_path, 'Settings', 'servercreds.json')) as f:
        #    creds = json.loads(f.read())
        creds = self.read_config()
        self.words_api = asposewordscloud.WordsApi(creds['ClientId'], creds['ClientSecret'], creds['BaseUrl'])

        if six.PY3:
            warnings.simplefilter("ignore", ResourceWarning)

    def upload_file(self, path, file):
        request = asposewordscloud.models.requests.UploadFileRequest(file, path)
        _result = self.words_api.upload_file(request)

    def create_random_guid(self):
        return str(uuid.uuid4())

if __name__ == '__main__':
    with open('testReport.xml', 'wb') as output:
        unittest.main(
            testRunner=xmlrunner.XMLTestRunner(output=output),
            failfast=False, buffer=False, catchbreak=False)



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="office_math_object.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class OfficeMathObject(object):
    """DTO container with an OfficeMath object.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'node_id': 'str',
        'content': 'StoryChildNodes',
        'display_type': 'str',
        'justification': 'str',
        'math_object_type': 'str'
    }

    attribute_map = {
        'link': 'Link',
        'node_id': 'NodeId',
        'content': 'Content',
        'display_type': 'DisplayType',
        'justification': 'Justification',
        'math_object_type': 'MathObjectType'
    }

    def __init__(self, link=None, node_id=None, content=None, display_type=None, justification=None, math_object_type=None):  # noqa: E501
        """OfficeMathObject - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._node_id = None
        self._content = None
        self._display_type = None
        self._justification = None
        self._math_object_type = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if node_id is not None:
            self.node_id = node_id
        if content is not None:
            self.content = content
        if display_type is not None:
            self.display_type = display_type
        if justification is not None:
            self.justification = justification
        if math_object_type is not None:
            self.math_object_type = math_object_type

    @property
    def link(self):
        """Gets the link of this OfficeMathObject.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this OfficeMathObject.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this OfficeMathObject.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this OfficeMathObject.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def node_id(self):
        """Gets the node_id of this OfficeMathObject.  # noqa: E501

        Gets or sets the node id.  # noqa: E501

        :return: The node_id of this OfficeMathObject.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this OfficeMathObject.

        Gets or sets the node id.  # noqa: E501

        :param node_id: The node_id of this OfficeMathObject.  # noqa: E501
        :type: str
        """
        self._node_id = node_id

    @property
    def content(self):
        """Gets the content of this OfficeMathObject.  # noqa: E501

        Gets or sets the content of a footnote.  # noqa: E501

        :return: The content of this OfficeMathObject.  # noqa: E501
        :rtype: StoryChildNodes
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this OfficeMathObject.

        Gets or sets the content of a footnote.  # noqa: E501

        :param content: The content of this OfficeMathObject.  # noqa: E501
        :type: StoryChildNodes
        """
        self._content = content

    @property
    def display_type(self):
        """Gets the display_type of this OfficeMathObject.  # noqa: E501

        Gets or sets the display format type of the OfficeMath object. This display format defines whether an equation is displayed inline with the text or displayed on its own line. Display format type has effect for top level Office Math only.Returned display format type is always Inline for nested Office Math.  # noqa: E501

        :return: The display_type of this OfficeMathObject.  # noqa: E501
        :rtype: str
        """
        return self._display_type

    @display_type.setter
    def display_type(self, display_type):
        """Sets the display_type of this OfficeMathObject.

        Gets or sets the display format type of the OfficeMath object. This display format defines whether an equation is displayed inline with the text or displayed on its own line. Display format type has effect for top level Office Math only.Returned display format type is always Inline for nested Office Math.  # noqa: E501

        :param display_type: The display_type of this OfficeMathObject.  # noqa: E501
        :type: str
        """
        allowed_values = ["Display", "Inline"]  # noqa: E501
        if not display_type.isdigit():
            if display_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `display_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(display_type, allowed_values))
            self._display_type = display_type
        else:
            self._display_type = allowed_values[int(display_type) if six.PY3 else long(display_type)]

    @property
    def justification(self):
        """Gets the justification of this OfficeMathObject.  # noqa: E501

        Gets or sets the justification of the OfficeMath object. Justification cannot be set to the Office Math with display format type Inline.Inline justification cannot be set to the Office Math with display format type Display.Corresponding DisplayType has to be set before setting Office Math justification.  # noqa: E501

        :return: The justification of this OfficeMathObject.  # noqa: E501
        :rtype: str
        """
        return self._justification

    @justification.setter
    def justification(self, justification):
        """Sets the justification of this OfficeMathObject.

        Gets or sets the justification of the OfficeMath object. Justification cannot be set to the Office Math with display format type Inline.Inline justification cannot be set to the Office Math with display format type Display.Corresponding DisplayType has to be set before setting Office Math justification.  # noqa: E501

        :param justification: The justification of this OfficeMathObject.  # noqa: E501
        :type: str
        """
        allowed_values = ["CenterGroup", "Default", "Center", "Left", "Right", "Inline"]  # noqa: E501
        if not justification.isdigit():
            if justification not in allowed_values:
                raise ValueError(
                    "Invalid value for `justification` ({0}), must be one of {1}"  # noqa: E501
                    .format(justification, allowed_values))
            self._justification = justification
        else:
            self._justification = allowed_values[int(justification) if six.PY3 else long(justification)]

    @property
    def math_object_type(self):
        """Gets the math_object_type of this OfficeMathObject.  # noqa: E501

        Gets or sets the type of the OfficeMath object.  # noqa: E501

        :return: The math_object_type of this OfficeMathObject.  # noqa: E501
        :rtype: str
        """
        return self._math_object_type

    @math_object_type.setter
    def math_object_type(self, math_object_type):
        """Sets the math_object_type of this OfficeMathObject.

        Gets or sets the type of the OfficeMath object.  # noqa: E501

        :param math_object_type: The math_object_type of this OfficeMathObject.  # noqa: E501
        :type: str
        """
        allowed_values = ["OMath", "OMathPara", "Accent", "Bar", "BorderBox", "Box", "Delimiter", "Degree", "Argument", "Array", "Fraction", "Denominator", "Numerator", "Function", "FunctionName", "GroupCharacter", "Limit", "LowerLimit", "UpperLimit", "Matrix", "MatrixRow", "NAry", "Phantom", "Radical", "SubscriptPart", "SuperscriptPart", "PreSubSuperscript", "Subscript", "SubSuperscript", "Supercript"]  # noqa: E501
        if not math_object_type.isdigit():
            if math_object_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `math_object_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(math_object_type, allowed_values))
            self._math_object_type = math_object_type
        else:
            self._math_object_type = allowed_values[int(math_object_type) if six.PY3 else long(math_object_type)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

        if self._link is not None:
            self._link.validate()




        if self._content is not None:
            self._content.validate()





    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfficeMathObject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="metafile_rendering_options_data.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class MetafileRenderingOptionsData(object):
    """Container class for options of metafile rendering.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'emf_plus_dual_rendering_mode': 'str',
        'emulate_raster_operations': 'bool',
        'emulate_rendering_to_size_on_page': 'bool',
        'emulate_rendering_to_size_on_page_resolution': 'int',
        'rendering_mode': 'str',
        'use_emf_embedded_to_wmf': 'bool'
    }

    attribute_map = {
        'emf_plus_dual_rendering_mode': 'EmfPlusDualRenderingMode',
        'emulate_raster_operations': 'EmulateRasterOperations',
        'emulate_rendering_to_size_on_page': 'EmulateRenderingToSizeOnPage',
        'emulate_rendering_to_size_on_page_resolution': 'EmulateRenderingToSizeOnPageResolution',
        'rendering_mode': 'RenderingMode',
        'use_emf_embedded_to_wmf': 'UseEmfEmbeddedToWmf'
    }

    def __init__(self, emf_plus_dual_rendering_mode=None, emulate_raster_operations=None, emulate_rendering_to_size_on_page=None, emulate_rendering_to_size_on_page_resolution=None, rendering_mode=None, use_emf_embedded_to_wmf=None):  # noqa: E501
        """MetafileRenderingOptionsData - a model defined in Swagger"""  # noqa: E501

        self._emf_plus_dual_rendering_mode = None
        self._emulate_raster_operations = None
        self._emulate_rendering_to_size_on_page = None
        self._emulate_rendering_to_size_on_page_resolution = None
        self._rendering_mode = None
        self._use_emf_embedded_to_wmf = None
        self.discriminator = None

        if emf_plus_dual_rendering_mode is not None:
            self.emf_plus_dual_rendering_mode = emf_plus_dual_rendering_mode
        if emulate_raster_operations is not None:
            self.emulate_raster_operations = emulate_raster_operations
        if emulate_rendering_to_size_on_page is not None:
            self.emulate_rendering_to_size_on_page = emulate_rendering_to_size_on_page
        if emulate_rendering_to_size_on_page_resolution is not None:
            self.emulate_rendering_to_size_on_page_resolution = emulate_rendering_to_size_on_page_resolution
        if rendering_mode is not None:
            self.rendering_mode = rendering_mode
        if use_emf_embedded_to_wmf is not None:
            self.use_emf_embedded_to_wmf = use_emf_embedded_to_wmf

    @property
    def emf_plus_dual_rendering_mode(self):
        """Gets the emf_plus_dual_rendering_mode of this MetafileRenderingOptionsData.  # noqa: E501

        Gets or sets the option that controls how EMF+ Dual metafiles should be rendered.  # noqa: E501

        :return: The emf_plus_dual_rendering_mode of this MetafileRenderingOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._emf_plus_dual_rendering_mode

    @emf_plus_dual_rendering_mode.setter
    def emf_plus_dual_rendering_mode(self, emf_plus_dual_rendering_mode):
        """Sets the emf_plus_dual_rendering_mode of this MetafileRenderingOptionsData.

        Gets or sets the option that controls how EMF+ Dual metafiles should be rendered.  # noqa: E501

        :param emf_plus_dual_rendering_mode: The emf_plus_dual_rendering_mode of this MetafileRenderingOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["EmfPlusWithFallback", "EmfPlus", "Emf"]  # noqa: E501
        if not emf_plus_dual_rendering_mode.isdigit():
            if emf_plus_dual_rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `emf_plus_dual_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(emf_plus_dual_rendering_mode, allowed_values))
            self._emf_plus_dual_rendering_mode = emf_plus_dual_rendering_mode
        else:
            self._emf_plus_dual_rendering_mode = allowed_values[int(emf_plus_dual_rendering_mode) if six.PY3 else long(emf_plus_dual_rendering_mode)]

    @property
    def emulate_raster_operations(self):
        """Gets the emulate_raster_operations of this MetafileRenderingOptionsData.  # noqa: E501

        Gets or sets a value indicating whether the raster operations should be emulated. Specific raster operations could be used in metafiles. They can not be rendered directly to vector graphics. Emulating raster operations requires partial rasterization of the resulting vector graphics which may affect the metafile rendering performance. When this value is set to true, Aspose.Words emulates the raster operations. The resulting output maybe partially rasterized and performance might be slower. When this value is set to false, Aspose.Words does not emulate the raster operations. When Aspose.Words encounters a raster operation in a metafile it fallbacks to rendering the metafile into a bitmap by using the operating system. This option is used only when metafile is rendered as vector graphics. The default value is true.  # noqa: E501

        :return: The emulate_raster_operations of this MetafileRenderingOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._emulate_raster_operations

    @emulate_raster_operations.setter
    def emulate_raster_operations(self, emulate_raster_operations):
        """Sets the emulate_raster_operations of this MetafileRenderingOptionsData.

        Gets or sets a value indicating whether the raster operations should be emulated. Specific raster operations could be used in metafiles. They can not be rendered directly to vector graphics. Emulating raster operations requires partial rasterization of the resulting vector graphics which may affect the metafile rendering performance. When this value is set to true, Aspose.Words emulates the raster operations. The resulting output maybe partially rasterized and performance might be slower. When this value is set to false, Aspose.Words does not emulate the raster operations. When Aspose.Words encounters a raster operation in a metafile it fallbacks to rendering the metafile into a bitmap by using the operating system. This option is used only when metafile is rendered as vector graphics. The default value is true.  # noqa: E501

        :param emulate_raster_operations: The emulate_raster_operations of this MetafileRenderingOptionsData.  # noqa: E501
        :type: bool
        """
        self._emulate_raster_operations = emulate_raster_operations

    @property
    def emulate_rendering_to_size_on_page(self):
        """Gets the emulate_rendering_to_size_on_page of this MetafileRenderingOptionsData.  # noqa: E501

        Gets or sets a value determining whether metafile rendering emulates the display of the metafile according to the size on page or the display of the metafile in its default size.  # noqa: E501

        :return: The emulate_rendering_to_size_on_page of this MetafileRenderingOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._emulate_rendering_to_size_on_page

    @emulate_rendering_to_size_on_page.setter
    def emulate_rendering_to_size_on_page(self, emulate_rendering_to_size_on_page):
        """Sets the emulate_rendering_to_size_on_page of this MetafileRenderingOptionsData.

        Gets or sets a value determining whether metafile rendering emulates the display of the metafile according to the size on page or the display of the metafile in its default size.  # noqa: E501

        :param emulate_rendering_to_size_on_page: The emulate_rendering_to_size_on_page of this MetafileRenderingOptionsData.  # noqa: E501
        :type: bool
        """
        self._emulate_rendering_to_size_on_page = emulate_rendering_to_size_on_page

    @property
    def emulate_rendering_to_size_on_page_resolution(self):
        """Gets the emulate_rendering_to_size_on_page_resolution of this MetafileRenderingOptionsData.  # noqa: E501

        Gets or sets the resolution in pixels per inch for the emulation of metafile rendering to the size on page. This option is used only when EmulateRenderingToSizeOnPage is set to true.The default value is 96. This is a default display resolution. I.e. metafile rendering will emulate the display of the metafile in MS Word with a 100% zoom factor.  # noqa: E501

        :return: The emulate_rendering_to_size_on_page_resolution of this MetafileRenderingOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._emulate_rendering_to_size_on_page_resolution

    @emulate_rendering_to_size_on_page_resolution.setter
    def emulate_rendering_to_size_on_page_resolution(self, emulate_rendering_to_size_on_page_resolution):
        """Sets the emulate_rendering_to_size_on_page_resolution of this MetafileRenderingOptionsData.

        Gets or sets the resolution in pixels per inch for the emulation of metafile rendering to the size on page. This option is used only when EmulateRenderingToSizeOnPage is set to true.The default value is 96. This is a default display resolution. I.e. metafile rendering will emulate the display of the metafile in MS Word with a 100% zoom factor.  # noqa: E501

        :param emulate_rendering_to_size_on_page_resolution: The emulate_rendering_to_size_on_page_resolution of this MetafileRenderingOptionsData.  # noqa: E501
        :type: int
        """
        self._emulate_rendering_to_size_on_page_resolution = emulate_rendering_to_size_on_page_resolution

    @property
    def rendering_mode(self):
        """Gets the rendering_mode of this MetafileRenderingOptionsData.  # noqa: E501

        Gets or sets the option that controls how metafile images should be rendered.  # noqa: E501

        :return: The rendering_mode of this MetafileRenderingOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._rendering_mode

    @rendering_mode.setter
    def rendering_mode(self, rendering_mode):
        """Sets the rendering_mode of this MetafileRenderingOptionsData.

        Gets or sets the option that controls how metafile images should be rendered.  # noqa: E501

        :param rendering_mode: The rendering_mode of this MetafileRenderingOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["VectorWithFallback", "Vector", "Bitmap"]  # noqa: E501
        if not rendering_mode.isdigit():
            if rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(rendering_mode, allowed_values))
            self._rendering_mode = rendering_mode
        else:
            self._rendering_mode = allowed_values[int(rendering_mode) if six.PY3 else long(rendering_mode)]

    @property
    def use_emf_embedded_to_wmf(self):
        """Gets the use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501

        Gets or sets the flag, that controls how WMF metafiles with embedded EMF metafiles should be rendered.  # noqa: E501

        :return: The use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._use_emf_embedded_to_wmf

    @use_emf_embedded_to_wmf.setter
    def use_emf_embedded_to_wmf(self, use_emf_embedded_to_wmf):
        """Sets the use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.

        Gets or sets the flag, that controls how WMF metafiles with embedded EMF metafiles should be rendered.  # noqa: E501

        :param use_emf_embedded_to_wmf: The use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
        :type: bool
        """
        self._use_emf_embedded_to_wmf = use_emf_embedded_to_wmf


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetafileRenderingOptionsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other